SystemOrganization addCategory: #ConfigurationOfPharo!

Object subclass: #ConfigurationOfPharo
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPharo'!

!ConfigurationOfPharo commentStamp: 'dkh 2/27/2011 13:09' prior: 0!
To load, execute the following in a PharoCore image:

	(ConfigurationOfPharo project version: #stable) load.
	
A different version will be loaded, based on whether the PharoCore image is 1.0, 1.1 or 1.2,
according to the following formula (at the time of this writing):

	Pharo10    '1.0-10517'
	Pharo1.1    '1.1'
	Pharo1.2    '1.2-beta2'

For a prebuilt image see:

  https://pharo-ic.lille.inria.fr/hudson/view/Pharo/
!

!ConfigurationOfPharo class methodsFor: 'private' stamp: 'MarianoMartinezPeck 12/6/2009 00:00'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfPharo class methodsFor: 'private' stamp: 'MarianoMartinezPeck 1/23/2011 10:51'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."
	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion.
		]! !

!ConfigurationOfPharo class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/6/2009 00:00'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPharo class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/6/2009 00:00'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfPharo class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/6/2009 00:00'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfPharo class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/6/2009 00:00'!
project

	^self new project! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'DaleHenrichs 3/15/2010 10:21'!
baseline10rc22: spec
	<version: '1.0-rc.2.2-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
			
				preLoadDoIt: #preloadForPharo;
				postLoadDoIt: #postloadForPharo;
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoSound'
					with:
						[ spec
								className: 'ConfigurationOfPharoSound';
								file: 'ConfigurationOfPharoSound';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'PharoMorphicExtras'
					with:
						[ spec
								className: 'ConfigurationOfPharoMorphicExtras';
								file: 'ConfigurationOfPharoMorphicExtras';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev Tests');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								loads: #('Core');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests') ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'ArchiveViewer' with: [ spec repository: 'http://www.squeaksource.com/PharoMorphicExtras' ].
			
			spec
				group: 'default' with: #('DevImageStandardOB');
				group: 'Pharo Extras' with: #('PharoSound' 'PharoMorphicExtras' 'ProfStef' );
				group: 'Dev Tools' with: #('RoelTyper' 'NewInspector' 'Shout' 'ArchiveViewer' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' );
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests' );
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'DevImageStandardOBWithoutTests' with: #('Dev Tools OB' 'Pharo Extras');
				group: 'DevImageStandardOB' with: #('Dev Tools OB Tests' 'DevImageStandardOBWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'dkh 2/26/2011 18:24'!
baseline10rc2: spec
	<version: '1.0-rc.2-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
			
				preLoadDoIt: #preloadForPharo;
				postLoadDoIt: #postloadForPharo;
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoSound'
					with:
						[ spec
								className: 'ConfigurationOfPharoSound';
								file: 'ConfigurationOfPharoSound';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'PharoMorphicExtras'
					with:
						[ spec
								className: 'ConfigurationOfPharoMorphicExtras';
								file: 'ConfigurationOfPharoMorphicExtras';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev Tests');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'Nile-All' with: [ spec repository: 'http://www.squeaksource.com/Nile' ];
				package: 'ArchiveViewer' with: [ spec repository: 'http://www.squeaksource.com/PharoMorphicExtras' ];
				package: 'ImageForDevelopers'
					with:
						[ spec
							file: 'ImageForDevelopers-pharo';
							repository: 'http://www.squeaksource.com/ImageForDevelopers';
							postLoadDoIt: #postLoadImageForDevelopers ].
			spec
				group: 'default' with: #('DevImageStandardOB');
				group: 'Pharo Extras' with: #('PharoSound' 'PharoMorphicExtras' 'Nile-All' );
				group: 'Dev Tools' with: #('RoelTyper' 'NewInspector' 'Shout' 'ArchiveViewer' 'OCompletion' 'AutomaticMethodCategorizer' );
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests');
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'DevImageStandardOBWithoutTests' with: #('Dev Tools OB' 'Pharo Extras' 'ImageForDevelopers');
				group: 'DevImageStandardOB' with: #('Dev Tools OB Tests' 'DevImageStandardOBWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'dkh 2/26/2011 18:26'!
baseline10rc3: spec
	<version: '1.0-rc.3-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				preLoadDoIt: #preloadForPharo;
				postLoadDoIt: #postloadForPharo;
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoSound'
					with:
						[ spec
								className: 'ConfigurationOfPharoSound';
								file: 'ConfigurationOfPharoSound';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'PharoMorphicExtras'
					with:
						[ spec
								className: 'ConfigurationOfPharoMorphicExtras';
								file: 'ConfigurationOfPharoMorphicExtras';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev Tests');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								loads: #('Core');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests') ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					"spec requires: 'Pharo'."
					spec postLoadDoIt: #postLoadImageForDevelopers.
					];
				package: 'ArchiveViewer' with: [ spec repository: 'http://www.squeaksource.com/PharoMorphicExtras' ].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Extras' with: #('PharoSound' 'PharoMorphicExtras' 'ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'NewInspector' 'Shout' 'ArchiveViewer' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests');
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests' with: #('Dev Tools OB' 'Pharo Extras' 'ImageForDevelopers' );
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:27'!
baseline111: spec
	<version: '1.1.1-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				preLoadDoIt: #preloadForPharo;
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					copyFrom: 'OB Dev'
					with: [ spec loads: #('Dev Tests') ];			
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ScriptManager'
					with:
						[ spec
								className: 'ConfigurationOfScriptManager';
								file: 'ConfigurationOfScriptManager';
								loads: 'ALL';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoNonCorePackages'
					with:
						[ spec
								className: 'ConfigurationOfPharoNonCore';
								file: 'ConfigurationOfPharoNonCore';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								loads: #('Core' 'Browser');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests')];
				project: 'Metacello'
					with:
						[ spec
								className: 'ConfigurationOfMetacello';
								file: 'ConfigurationOfMetacello';
								loads: #('Metacello-Core' 'Tutorial' 'UI' 'Metacello-ProfStef' 'Metacello-Help');
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Metacello Tests'
					copyFrom: 'Metacello'
					with: [ spec loads: #('Tests') ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'Pharo-Project-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					spec postLoadDoIt: #postLoadImageForDevelopers ].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Non Core Packages' with: #('PharoNonCorePackages');
				group: 'Pharo Extras' with: #('ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'NewInspector' 'Shout' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' 'ScriptManager' 'Metacello');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests' 'Metacello Tests' );
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests'
					with: #('Dev Tools OB' 'Pharo Extras' 'Pharo Non Core Packages' 'ImageForDevelopers');
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:26'!
baseline11: spec
	<version: '1.1-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				preLoadDoIt: #preloadForPharo;
				postLoadDoIt: #postloadForPharo;
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
					project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ScriptManager'
					with:
						[ spec
								className: 'ConfigurationOfScriptManager';
								file: 'ConfigurationOfScriptManager';
								loads: 'ALL';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];			
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoNonCorePackages'
					with:
						[ spec
								className: 'ConfigurationOfPharoNonCore';
								file: 'ConfigurationOfPharoNonCore';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev Tests');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								loads: #('Core' 'Browser');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests') ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					spec postLoadDoIt: #postLoadImageForDevelopers.
					].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Non Core Packages' with: #('PharoNonCorePackages');
				group: 'Pharo Extras' with: #('ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'NewInspector' 'Shout' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' 'ScriptManager');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests');
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests' with: #('Dev Tools OB' 'Pharo Extras' 'Pharo Non Core Packages' 'ImageForDevelopers' );
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:26'!
baseline11beta1: spec
	<version: '1.1-beta.1-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				preLoadDoIt: #preloadForPharo;
				postLoadDoIt: #postloadForPharo;
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ScriptManager'
					with:
						[ spec
								className: 'ConfigurationOfScriptManager';
								file: 'ConfigurationOfScriptManager';
								loads: 'ALL';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoNonCorePackages'
					with:
						[ spec
								className: 'ConfigurationOfPharoNonCore';
								file: 'ConfigurationOfPharoNonCore';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev Tests');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								loads: #('Core' 'Browser');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests') ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					spec postLoadDoIt: #postLoadImageForDevelopers ].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Non Core Packages' with: #('PharoNonCorePackages');
				group: 'Pharo Extras' with: #('ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'NewInspector' 'Shout' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' 'ScriptManager');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests');
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests'
					with: #('Dev Tools OB' 'Pharo Extras' 'Pharo Non Core Packages' 'ImageForDevelopers');
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:26'!
baseline11rc2: spec
	<version: '1.1-rc2-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				preLoadDoIt: #preloadForPharo;
				postLoadDoIt: #postloadForPharo;
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					copyFrom: 'OB Dev'
					with: [ spec loads: #('Dev Tests') ];			
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ScriptManager'
					with:
						[ spec
								className: 'ConfigurationOfScriptManager';
								file: 'ConfigurationOfScriptManager';
								loads: 'ALL';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoNonCorePackages'
					with:
						[ spec
								className: 'ConfigurationOfPharoNonCore';
								file: 'ConfigurationOfPharoNonCore';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'NewInspector'
					with:
						[ spec
								className: 'ConfigurationOfNewInspector';
								file: 'ConfigurationOfNewInspector';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								loads: #('Core' 'Browser');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests')];
				project: 'Metacello'
					with:
						[ spec
								className: 'ConfigurationOfMetacello';
								file: 'ConfigurationOfMetacello';
								loads: #('Metacello-Core' 'Tutorial' 'UI' 'Metacello-ProfStef' 'Metacello-Help');
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Metacello Tests'
					copyFrom: 'Metacello'
					with: [ spec loads: #('Tests') ].
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'Pharo-Project-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					spec postLoadDoIt: #postLoadImageForDevelopers ].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Non Core Packages' with: #('PharoNonCorePackages');
				group: 'Pharo Extras' with: #('ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'NewInspector' 'Shout' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' 'ScriptManager' 'Metacello');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests' 'Metacello Tests' );
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests'
					with: #('Dev Tools OB' 'Pharo Extras' 'Pharo Non Core Packages' 'ImageForDevelopers');
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.2' stamp: 'dkh 2/26/2011 18:27'!
baseline12: spec
	<version: '1.2-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					copyFrom: 'OB Dev'
					with: [ spec loads: #('Dev Tests') ];			
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ScriptManager'
					with:
						[ spec
								className: 'ConfigurationOfScriptManager';
								file: 'ConfigurationOfScriptManager';
								loads: 'ALL';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoNonCorePackages'
					with:
						[ spec
								className: 'ConfigurationOfPharoNonCore';
								file: 'ConfigurationOfPharoNonCore';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								versionString: '1.6-baseline';
								loads: #('Core' 'Help');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests')];
				project: 'Metacello'
					with:
						[ spec
								className: 'ConfigurationOfMetacello';
								file: 'ConfigurationOfMetacello';
								loads: #('Metacello-Core' 'Tutorial' 'UI' 'Metacello-ProfStef' 'Metacello-Help');
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Metacello Tests'
					copyFrom: 'Metacello'
					with: [ spec loads: #('Tests') ];
				project: 'MemoryMonitor'
					with:
						[ spec
								className: 'ConfigurationOfMemoryMonitor';
								file: 'ConfigurationOfMemoryMonitor';
								repository: 'http://www.squeaksource.com/MemoryMonitor' ];
							
							
				project: 'Autotest'
					with:
						[ spec
								className: 'ConfigurationOfAutotest';
								loads: #('Dev');
								file: 'ConfigurationOfAutotest';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Autotest Help Tests'
					copyFrom: 'Autotest'
					with: [ spec loads: #('Help' 'Tests') ];
					
					
				project: 'XMLSupport'
					with:
						[ spec
								className: 'ConfigurationOfXMLSupport';
								loads: #('Core');
								file: 'ConfigurationOfXMLSupport';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'XMLSupport Tests'
					copyFrom: 'XMLSupport'
					with: [ spec loads: #('Tests') ].
					
					
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'Pharo-Project-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'Smalltalk-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'Shortcuts-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					spec postLoadDoIt: #postLoadImageForDevelopers ].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Non Core Packages' with: #('PharoNonCorePackages');
				group: 'Pharo Extras' with: #('ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Help' with: #('Shortcuts-Help' 'Pharo-Project-Help' 'Smalltalk-Help');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'Shout' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' 'ScriptManager' 'Metacello' 'MemoryMonitor' 'Autotest' 'XMLSupport');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests' 'Metacello Tests'  'Autotest Help Tests' 'XMLSupport Tests');
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests'
					with: #('Dev Tools OB' 'Pharo Extras' 'Pharo Non Core Packages' 'ImageForDevelopers');
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests' 'Help');
				yourself ]! !

!ConfigurationOfPharo methodsFor: '1.3' stamp: 'MarcusDenker 3/22/2011 16:17'!
baseline13: spec
	<version: '1.3-baseline'>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #pharo
		do:
			[ spec
				project: 'OB Dev'
					with:
						[ spec
								className: 'ConfigurationOfOmniBrowser';
								loads: #('Dev');
								file: 'ConfigurationOfOmniBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OB Dev Tests'
					copyFrom: 'OB Dev'
					with: [ spec loads: #('Dev Tests') ];			
				project: 'AutomaticMethodCategorizer'
					with:
						[ spec
								className: 'ConfigurationOfAutomaticMethodCategorizer';
								file: 'ConfigurationOfAutomaticMethodCategorizer';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ScriptManager'
					with:
						[ spec
								className: 'ConfigurationOfScriptManager';
								file: 'ConfigurationOfScriptManager';
								loads: 'ALL';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout'
					with:
						[ spec
								className: 'ConfigurationOfShout';
								loads: #('Core');
								file: 'ConfigurationOfShout';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Shout Tests'
					copyFrom: 'Shout'
					with: [ spec loads: #('Tests') ];
				project: 'OCompletion'
					with:
						[ spec
								className: 'ConfigurationOfOCompletion';
								loads: #('Core');
								file: 'ConfigurationOfOCompletion';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'OCompletion Tests'
					copyFrom: 'OCompletion'
					with: [ spec loads: #('Tests') ];
				project: 'PharoNonCorePackages'
					with:
						[ spec
								className: 'ConfigurationOfPharoNonCore';
								file: 'ConfigurationOfPharoNonCore';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser'
					with:
						[ spec
								className: 'ConfigurationOfRefactoringBrowser';
								loads: #('Core');
								file: 'ConfigurationOfRefactoringBrowser';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'RefactoringBrowser Tests'
					copyFrom: 'RefactoringBrowser'
					with: [ spec loads: #('Tests') ];
				project: 'Nile'
					with:
						[ spec
								className: 'ConfigurationOfNile';
								loads: #('Core');
								file: 'ConfigurationOfNile';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Nile Tests'
					copyFrom: 'Nile'
					with: [ spec loads: #('Tests') ];
				project: 'ProfStef'
					with:
						[ spec
								className: 'ConfigurationOfProfStef';
								versionString: '1.6-baseline';
								loads: #('Core' 'Help');
								file: 'ConfigurationOfProfStef';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ProfStef Tests'
					copyFrom: 'ProfStef'
					with: [ spec loads: #('Tests')];
				project: 'Metacello'
					with:
						[ spec
								className: 'ConfigurationOfMetacello';
								file: 'ConfigurationOfMetacello';
								loads: #('Metacello-Core' 'Tutorial' 'UI' 'Metacello-ProfStef' 'Metacello-Help');
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Metacello Tests'
					copyFrom: 'Metacello'
					with: [ spec loads: #('Tests') ];
				project: 'MemoryMonitor'
					with:
						[ spec
								className: 'ConfigurationOfMemoryMonitor';
								file: 'ConfigurationOfMemoryMonitor';
								repository: 'http://www.squeaksource.com/MemoryMonitor' ];
							
							
				project: 'Autotest'
					with:
						[ spec
								className: 'ConfigurationOfAutotest';
								loads: #('Dev');
								file: 'ConfigurationOfAutotest';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'Autotest Help Tests'
					copyFrom: 'Autotest'
					with: [ spec loads: #('Help' 'Tests') ];
					
					
				project: 'XMLSupport'
					with:
						[ spec
								className: 'ConfigurationOfXMLSupport';
								loads: #('Core');
								file: 'ConfigurationOfXMLSupport';
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'XMLSupport Tests'
					copyFrom: 'XMLSupport'
					with: [ spec loads: #('Tests') ].
					
					
			spec
				package: 'RoelTyper' with: [ spec repository: 'http://www.squeaksource.com/RoelTyper' ];
				package: 'Pharo-Project-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'Smalltalk-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'Shortcuts-Help' with: [ spec repository: 'http://www.squeaksource.com/HelpSystem' ];
				package: 'ImageForDevelopers' with: [ 
					spec file: 'ImageForDevelopers-pharo'.
					spec repository: 'http://www.squeaksource.com/ImageForDevelopers'.
					spec postLoadDoIt: #postLoadImageForDevelopers ].
			spec
				group: 'default' with: #('PharoDev');
				group: 'Pharo Non Core Packages' with: #('PharoNonCorePackages');
				group: 'Pharo Extras' with: #('ProfStef');
				group: 'Pharo Extras Tests' with: #('ProfStef Tests');
				group: 'Help' with: #('Shortcuts-Help' 'Pharo-Project-Help' 'Smalltalk-Help');
				group: 'Dev Tools'
					with:
						#('RoelTyper' 'Shout' 'OCompletion' 'AutomaticMethodCategorizer' 'RefactoringBrowser' 'Nile' 'ScriptManager' 'Metacello' 'MemoryMonitor' 'Autotest' 'XMLSupport');
				group: 'Dev Tools Tests' with: #('Shout Tests' 'OCompletion Tests' 'Nile Tests' 'RefactoringBrowser Tests' 'Metacello Tests'  'Autotest Help Tests' 'XMLSupport Tests');
				group: 'Dev Tools OB' with: #('Dev Tools' 'OB Dev');
				group: 'Dev Tools OB Tests' with: #('Dev Tools Tests' 'OB Dev Tests');
				group: 'PharoDevWithoutTests'
					with: #('Dev Tools OB' 'Pharo Extras' 'Pharo Non Core Packages' 'ImageForDevelopers');
				group: 'PharoDev' with: #('Dev Tools OB Tests' 'Pharo Extras Tests' 'PharoDevWithoutTests' 'Help');
				yourself ]! !

!ConfigurationOfPharo methodsFor: 'pre/post load' stamp: 'MarianoMartinezPeck 4/28/2010 10:34'!
postLoadImageForDevelopers
	(Smalltalk classNamed: #DEVImageCreator) default install.! !

!ConfigurationOfPharo methodsFor: 'pre/post load' stamp: 'MarianoMartinezPeck 1/8/2010 20:53'!
postloadForPharo

	Preferences enable: #showDeprecationWarnings.! !

!ConfigurationOfPharo methodsFor: 'pre/post load' stamp: 'sd 2/27/2011 16:06'!
postloadForPharo12
	Deprecation raiseWarning: true.
	SHTextStylerST80 initialize.! !

!ConfigurationOfPharo methodsFor: 'pre/post load' stamp: 'MarianoMartinezPeck 1/8/2010 20:52'!
preloadForPharo

	Preferences disable: #showDeprecationWarnings.
! !

!ConfigurationOfPharo methodsFor: 'pre/post load' stamp: 'MarianoMartinezPeck 1/23/2011 10:51'!
preloadForPharo12
	Deprecation raiseWarning: false.
! !

!ConfigurationOfPharo methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 13:07'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project. 
		project loadType: #linear.
		project ]! !

!ConfigurationOfPharo methodsFor: 'symbolic versions' stamp: 'GuillermoPolito 2/18/2011 00:19'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'pharo1.0.x' version: '1.0-10517'. 
	spec for: #'pharo1.1.x' version: '1.1'. 
	spec for: #'pharo1.2.x' version: '1.2-beta2'.
! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'dkh 2/26/2011 18:18'!
version1010517: spec
	<version: '1.0-10517' imports: #('1.0-rc.3-baseline')>
	spec for: #common
		do:
			[ spec blessing: #development.
			spec author: 'MarianoMartinezPeck'.
			spec description: 'Official Pharo 1.0 release.
- Little OB fixes.
- Updated workspace workspace' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.223';
				package: 'ArchiveViewer' with: 'ArchiveViewer-MarianoMartinezPeck.3'.
			spec
				project: 'PharoSound' with: '1.0';
				project: 'PharoMorphicExtras' with: '1.0';
				project: 'NewInspector' with: '1.1';
				project: 'Shout' with: '1.0';
				project: 'Shout Tests' with: '1.0';
				project: 'OCompletion' with: '1.1';
				project: 'OCompletion Tests' with: '1.1';
				project: 'OB Dev' with: '1.1.3';
				project: 'OB Dev Tests' with: '1.1.3';
				project: 'AutomaticMethodCategorizer' with: '1.1';
				project: 'RefactoringBrowser' with: '1.2.1';
				project: 'RefactoringBrowser Tests' with: '1.2.1';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.0';
				project: 'ProfStef Tests' with: '1.0' ]! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'dkh 2/26/2011 18:13'!
version10rc10505: spec
	<version: '1.0-rc2.10505' imports: #('1.0-rc.2-baseline')>

	spec for: #common
		do:
			[ spec blessing: #rc.
			spec author: 'MarianoMartinezPeck'.
			spec description: 'This is a first attemp to create a configuration for Pharo' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'Nile-All' with: 'Nile-All-cyrille_delaunay.154';
				package: 'ArchiveViewer' with: 'ArchiveViewer-MarianoMartinezPeck.3';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.198'.
			spec
				project: 'PharoSound' with: '1.0';
				project: 'PharoMorphicExtras' with: '1.0';
				project: 'NewInspector' with: '1.0';
				project: 'Shout' with: '1.0';
				project: 'Shout Tests' with: '1.0';
				project: 'OCompletion' with: '1.0';
				project: 'OCompletion Tests' with: '1.0';
				project: 'OB Dev' with: '1.0';
				project: 'OB Dev Tests' with: '1.0';
				project: 'AutomaticMethodCategorizer' with: '1.0' ]! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'DaleHenrichs 12/16/2010 16:11'!
version10rc210508: spec
	<version: '1.0-rc2.10508' imports: #('1.0-rc.2.2-baseline')>
	spec for: #common
		do:
			[ spec blessing: #rc2.
			spec author: 'MarianoMartinezPeck'.
			spec description: '
This is 1.0 RC2. Please, look at this image in a nice way because it is very likely that if there is no big issue, it will be 1.0 official. We need to release 1.0.


Issues fixed:  In addition to the bugixes from the PharoCore, 1033, 1182, 1826, 1862.

Big changes:

- Now we use OB from Lukas Renggli repository and we have ALL TESTS GREEN!!!!!!     Thanks Lukas!!
- O2 loads again in the image without breaking OB. Read the workspace to see how to install it. Thanks David and Alexandre!!
- We have almost ALL TESTS of the PharoDev image in green. They are almost than 8800.

Smaller changes:

- Fixed the problem with Metacello and OCompletion. No more overrides.
- System -> About now shows the real Pharo name, not the core. I am also being "compatible" with the new SystemVersion that we have in 1.1  :)   Thanks Michael and Miguel!!
- I didn''t left again my proxy settings. I fixed this in my build scripts. It should be clean  :)
- Mercury bar is back again. If you want to disable:  Preferences disable: #mercuryPanel.
- Added a lot of cleanups after creating the image, including condensing .changes
- Added Refactoring-Spelling again.   Thanks Stan!!
- I wrote a ConfigurationOfNile instead of Nile-All and depends on Monticello dependencies.
- New welcome workspaces. Also getting started workspace and another workspace explaining how to load external packages like Seaside (2.8 and 3), Magritte, Pier, Moose, GetTools, O2, etc. Finally it is also added a link to the new ProfStef :)
Do you think that with this we are able to close issue1479 ?
- Background with Pharo picture. This was a joke. It looked nice :)    I promise I don''t put it again if you don''t like. To remove it evaluate:
World color: Color white.
- Enable the preference fastDragWindowForMorphic. Sorry, but it most computers this works REALLY slow. If you want them back, just disable it.
- When installing Seaside now doesn''t ask for user and password ( admin/seaside ). In addition, the Seaside Control Panel is only isntalled if OB is installed. This means that yu can install it in core or dev. Thanks Dale!!
- Disable of System Update for Dev images as it is not working properly.

' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ArchiveViewer' with: 'ArchiveViewer-MarianoMartinezPeck.3'.
			spec
				project: 'PharoSound' with: '1.0';
				project: 'PharoMorphicExtras' with: '1.0';
				project: 'NewInspector' with: '1.0';
				project: 'Shout' with: '1.0';
				project: 'Shout Tests' with: '1.0';
				project: 'OCompletion' with: '1.1';
				project: 'OCompletion Tests' with: '1.1';
				project: 'OB Dev' with: '1.1';
				project: 'OB Dev Tests' with: '1.1';
				project: 'AutomaticMethodCategorizer' with: '1.1';
				project: 'RefactoringBrowser' with: '1.1';
				project: 'RefactoringBrowser Tests' with: '1.1';
				project: 'Nile' with: '1.0';
				project: 'Nile Tests' with: '1.0' ;	
				project: 'ProfStef' with: '1.0';
				project: 'ProfStef Tests' with: '1.0' ]! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'dkh 2/26/2011 18:18'!
version10rc310515: spec
	<version: '1.0-rc3.10515' imports: #('1.0-rc.3-baseline')>
	spec for: #common
		do:
			[ spec blessing: #release.
			spec author: 'MarianoMartinezPeck'.
			spec description: '' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.220';
				package: 'ArchiveViewer' with: 'ArchiveViewer-MarianoMartinezPeck.3'.
			spec
				project: 'PharoSound' with: '1.0';
				project: 'PharoMorphicExtras' with: '1.0';
				project: 'NewInspector' with: '1.1';
				project: 'Shout' with: '1.0';
				project: 'Shout Tests' with: '1.0';
				project: 'OCompletion' with: '1.1';
				project: 'OCompletion Tests' with: '1.1';
				project: 'OB Dev' with: '1.1.1';
				project: 'OB Dev Tests' with: '1.1.1';
				project: 'AutomaticMethodCategorizer' with: '1.1';
				project: 'RefactoringBrowser' with: '1.2';
				project: 'RefactoringBrowser Tests' with: '1.2';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.0';
				project: 'ProfStef Tests' with: '1.0' ]! !

!ConfigurationOfPharo methodsFor: '1.0' stamp: 'dkh 2/26/2011 18:18'!
version10rc410517: spec
	<version: '1.0-rc4.10517' imports: #('1.0-rc.3-baseline')>
	spec for: #common
		do:
			[ spec blessing: #release.
			spec author: 'MarianoMartinezPeck'.
			spec description: '
- Little OB fixes
- Now we have preload Metacello version 1.0-beta.25
- Little fix in changelog.txt
- Updated links in workspace' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-EstebanLorenzano.222';
				package: 'ArchiveViewer' with: 'ArchiveViewer-MarianoMartinezPeck.3'.
			spec
				project: 'PharoSound' with: '1.0';
				project: 'PharoMorphicExtras' with: '1.0';
				project: 'NewInspector' with: '1.1';
				project: 'Shout' with: '1.0';
				project: 'Shout Tests' with: '1.0';
				project: 'OCompletion' with: '1.1';
				project: 'OCompletion Tests' with: '1.1';
				project: 'OB Dev' with: '1.1.2';
				project: 'OB Dev Tests' with: '1.1.2';
				project: 'AutomaticMethodCategorizer' with: '1.1';
				project: 'RefactoringBrowser' with: '1.2.1';
				project: 'RefactoringBrowser Tests' with: '1.2.1';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.0';
				project: 'ProfStef Tests' with: '1.0' ]! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:18'!
version111: spec
	<version: '1.1.1' imports: #('1.1.1-baseline')>
	spec for: #common
		do:
			[ spec blessing: #development.
			spec author: 'Mariano Martinez Peck'.
			spec description: '' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-FredericPluquet.82';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.242';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.1';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1.1';
				project: 'Shout Tests' with: '1.1.1';
				project: 'OCompletion' with: '1.2';
				project: 'OCompletion Tests' with: '1.2';
				project: 'OB Dev' with: '1.2';
				project: 'OB Dev Tests' with: '1.2';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.6';
				project: 'RefactoringBrowser Tests' with: '1.6';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27.4';
				project: 'Metacello Tests' with: '1.0-beta.27.4']! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:16'!
version11367Beta1: spec
	<version: '1.1-beta1.10517' imports: #('1.1-beta.1-baseline')>
	spec for: #common
		do:
			[ spec blessing: #release.
			spec author: 'Mariano Martinez Peck'.
			spec description: 'Release of PharoDev 1.1 beta1' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.235'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.0';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1';
				project: 'Shout Tests' with: '1.1';
				project: 'OCompletion' with: '1.1.1';
				project: 'OCompletion Tests' with: '1.1.1';
				project: 'OB Dev' with: '1.1.4';
				project: 'OB Dev Tests' with: '1.1.4';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.3';
				project: 'RefactoringBrowser Tests' with: '1.3';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2' ]! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:17'!
version11400rc2: spec
	<version: '1.1-rc2.11400' imports: #('1.1-rc2-baseline')>
	spec for: #common
		do:
			[ spec blessing: #releaseCandidate.
			spec author: 'Mariano Martinez Peck'.
			spec description: 'Release of PharoDev 1.1 beta1' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.239';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.1';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1';
				project: 'Shout Tests' with: '1.1';
				project: 'OCompletion' with: '1.1.1';
				project: 'OCompletion Tests' with: '1.1.1';
				project: 'OB Dev' with: '1.1.4';
				project: 'OB Dev Tests' with: '1.1.4';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.4';
				project: 'RefactoringBrowser Tests' with: '1.4';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27';
				project: 'Metacello Tests' with: '1.0-beta.27']! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:17'!
version11406rc3: spec
	<version: '1.1-rc3.11406' imports: #('1.1-rc2-baseline')>
	spec for: #common
		do:
			[ spec blessing: #releaseCandidate.
			spec author: 'Mariano Martinez Peck'.
			spec description: '' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-DamienCassou.80';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.239';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.1';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1';
				project: 'Shout Tests' with: '1.1';
				project: 'OCompletion' with: '1.1.1';
				project: 'OCompletion Tests' with: '1.1.1';
				project: 'OB Dev' with: '1.1.5';
				project: 'OB Dev Tests' with: '1.1.5';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.5';
				project: 'RefactoringBrowser Tests' with: '1.5';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27';
				project: 'Metacello Tests' with: '1.0-beta.27']! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:17'!
version11409rc4: spec
	<version: '1.1-rc4.11409' imports: #('1.1-rc2-baseline')>
	spec for: #common
		do:
			[ spec blessing: #development.
			spec author: 'Mariano Martinez Peck'.
			spec description: '' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-MarianoMartinezPeck.81';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.239';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.1';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1';
				project: 'Shout Tests' with: '1.1';
				project: 'OCompletion' with: '1.1.2';
				project: 'OCompletion Tests' with: '1.1.2';
				project: 'OB Dev' with: '1.1.5';
				project: 'OB Dev Tests' with: '1.1.5';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.5';
				project: 'RefactoringBrowser Tests' with: '1.5';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27';
				project: 'Metacello Tests' with: '1.0-beta.27']! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:17'!
version11410rc4: spec
	<version: '1.1-rc4.11410' imports: #('1.1-rc2-baseline')>
	spec for: #common
		do:
			[ spec blessing: #development.
			spec author: 'Mariano Martinez Peck'.
			spec description: '' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-MarianoMartinezPeck.81';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.240';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.1';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1';
				project: 'Shout Tests' with: '1.1';
				project: 'OCompletion' with: '1.1.2';
				project: 'OCompletion Tests' with: '1.1.2';
				project: 'OB Dev' with: '1.1.5';
				project: 'OB Dev Tests' with: '1.1.5';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.5';
				project: 'RefactoringBrowser Tests' with: '1.5';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27.1';
				project: 'Metacello Tests' with: '1.0-beta.27.1']! !

!ConfigurationOfPharo methodsFor: '1.1' stamp: 'dkh 2/26/2011 18:17'!
version11: spec
	<version: '1.1' imports: #('1.1-rc2-baseline')>
	spec for: #common
		do:
			[ spec blessing: #release.
			spec author: 'Mariano Martinez Peck'.
			spec description: '' ].
		
	spec for: #pharo
		do:
			[ spec
				package: 'RoelTyper' with: 'RoelTyper-MarianoMartinezPeck.81';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.240';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'PharoNonCorePackages' with: '1.1.1';
				project: 'NewInspector' with: '1.2';
				project: 'Shout' with: '1.1';
				project: 'Shout Tests' with: '1.1';
				project: 'OCompletion' with: '1.1.2';
				project: 'OCompletion Tests' with: '1.1.2';
				project: 'OB Dev' with: '1.1.5';
				project: 'OB Dev Tests' with: '1.1.5';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.5';
				project: 'RefactoringBrowser Tests' with: '1.5';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.1';
				project: 'ProfStef Tests' with: '1.1';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27.1';
				project: 'Metacello Tests' with: '1.0-beta.27.1']! !

!ConfigurationOfPharo methodsFor: '1.2' stamp: 'dkh 2/26/2011 18:19'!
version12beta1: spec
	<version: '1.2-beta' imports: #('1.2-baseline')>
	spec for: #common
		do: [ spec blessing: #development.
			 spec author: 'Guillermo Polito'.
			 spec description: 'Version for pharo 1.2 dev'.
			].
		
	spec for: #pharo
		do:
			[ spec
				package: 'Shortcuts-Help' with: 'Shortcuts-Help-LaurentLaffont.2';
				package: 'Smalltalk-Help' with: 'Smalltalk-Help-tbn.2';
				package: 'RoelTyper' with: 'RoelTyper-FredericPluquet.82';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.242';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'Autotest' with: '1.0';
				project: 'Autotest Help Tests' with: '1.0';
				project: 'MemoryMonitor' with: '1.0.3';
				project: 'XMLSupport' with: '1.1.6';
				project: 'XMLSupport Tests' with: '1.1.6';
				project: 'PharoNonCorePackages' with: '1.2';
				project: 'Shout' with: '1.2.1';
				project: 'Shout Tests' with: '1.2.1';
				project: 'OCompletion' with: '1.2.1';
				project: 'OCompletion Tests' with: '1.2.1';
				project: 'OB Dev' with: '1.2';
				project: 'OB Dev Tests' with: '1.2';
				project: 'AutomaticMethodCategorizer' with: '1.1.1';
				project: 'RefactoringBrowser' with: '1.6';
				project: 'RefactoringBrowser Tests' with: '1.6';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.6';
				project: 'ProfStef Tests' with: '1.6';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27.4';
				project: 'Metacello Tests' with: '1.0-beta.27.4']! !

!ConfigurationOfPharo methodsFor: '1.2' stamp: 'MarcusDenker 3/22/2011 16:05'!
version12beta2: spec
	"
	(self project version: '1.2-beta2') load
	"
	<version: '1.2-beta2' imports: #('1.2-baseline')>
	spec for: #common
		do: [ spec blessing: #development.
			 spec author: 'Stephane Ducasse'.
			 spec description: 'Version for pharo 1.2 dev'.
			].
		
	spec for: #pharo
		do:
			[
			spec 
				preLoadDoIt: #preloadForPharo12;
				postLoadDoIt: #postloadForPharo12.
			spec
				package: 'RoelTyper' with: 'RoelTyper-FredericPluquet.82';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarcusDenker.254';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9';
				package: 'Smalltalk-Help' with: 'Smalltalk-Help-tbn.2';				
				package: 'Shortcuts-Help' with: 'Shortcuts-Help-LaurentLaffont.2'.
			spec
				project: 'PharoNonCorePackages' with: '1.2';
				project: 'Shout' with: '1.2.2';
				project: 'Shout Tests' with: '1.2.2';
				project: 'OCompletion' with: '1.2.2';
				project: 'OCompletion Tests' with: '1.2.2';
				project: 'OB Dev' with: '1.2.4';
				project: 'OB Dev Tests' with: '1.2.4';
				project: 'AutomaticMethodCategorizer' with: '1.2';
				project: 'RefactoringBrowser' with: '1.7';
				project: 'RefactoringBrowser Tests' with: '1.7';
				project: 'Nile' with: '1.2';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.6';
				project: 'ProfStef Tests' with: '1.6';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.28.3.1';
				project: 'Metacello Tests' with: '1.0-beta.28.3.1';
				project: 'MemoryMonitor' with: '1.0.2';
				project: 'Autotest' with: '1.0.1';
				project: 'Autotest Help Tests' with: '1.0';
				project: 'XMLSupport' with: '1.1.6';
				project: 'XMLSupport Tests' with: '1.1.6'.
				]! !

!ConfigurationOfPharo methodsFor: '1.3' stamp: 'MarianoMartinezPeck 4/30/2011 00:57'!
version13beta1: spec
	<version: '1.3-beta' imports: #('1.3-baseline')>
	spec for: #common
		do: [ spec blessing: #beta.
			 spec author: 'Marcus Denker'.
			 spec description: 'Version for pharo 1.3 dev'.
			].
		
	spec for: #pharo
		do:
			[ spec
				package: 'Shortcuts-Help' with: 'Shortcuts-Help-LaurentLaffont.2';
				package: 'Smalltalk-Help' with: 'Smalltalk-Help-tbn.2';
				package: 'RoelTyper' with: 'RoelTyper-FredericPluquet.82';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.257';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.9'.
			spec
				project: 'Autotest' with: '1.0';
				project: 'Autotest Help Tests' with: '1.0';
				project: 'MemoryMonitor' with: '1.0.3';
				project: 'XMLSupport' with: '1.1.6';
				project: 'XMLSupport Tests' with: '1.1.6';
				project: 'PharoNonCorePackages' with: '1.2';
				project: 'Shout' with: '1.3';
				project: 'Shout Tests' with: '1.3';
				project: 'OCompletion' with: '1.3';
				project: 'OCompletion Tests' with: '1.3';
				project: 'OB Dev' with: '1.3';
				project: 'OB Dev Tests' with: '1.3';
				project: 'ConfigurationOfAutomaticMethodCategorizer' with: '1.3';
				project: 'RefactoringBrowser' with: '1.6';
				project: 'RefactoringBrowser Tests' with: '1.6';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.7';
				project: 'ProfStef Tests' with: '1.7';
				project: 'ScriptManager' with: '1.2';
				project: 'Metacello' with: '1.0-beta.27.4';
				project: 'Metacello Tests' with: '1.0-beta.27.4']! !

!ConfigurationOfPharo methodsFor: '1.3' stamp: 'MarianoMartinezPeck 4/30/2011 00:58'!
version13beta2: spec
	<version: '1.3-beta2' imports: #('1.3-baseline')>
	spec for: #common
		do: [ spec blessing: #development.
			 spec author: 'Mariano Martinez Peck'.
			 spec description: 'Version for pharo 1.3 dev'.
			].
		
	spec for: #pharo
		do:
			[ spec
				package: 'Shortcuts-Help' with: 'Shortcuts-Help-LaurentLaffont.2';
				package: 'Smalltalk-Help' with: 'Smalltalk-Help-tbn.2';
				package: 'RoelTyper' with: 'RoelTyper-FredericPluquet.82';
				package: 'ImageForDevelopers' with: 'ImageForDevelopers-pharo-MarianoMartinezPeck.257';
				package: 'Pharo-Project-Help' with: 'Pharo-Project-Help-tbn.10'.
			spec
				project: 'Autotest' with: '1.1';
				project: 'Autotest Help Tests' with: '1.1';
				project: 'MemoryMonitor' with: '1.0.3';
				project: 'XMLSupport' with: '1.2.0';
				project: 'XMLSupport Tests' with: '1.2.0';
				project: 'PharoNonCorePackages' with: '1.2';
				project: 'Shout' with: '1.3';
				project: 'Shout Tests' with: '1.3';
				project: 'OCompletion' with: '1.3';
				project: 'OCompletion Tests' with: '1.3';
				project: 'OB Dev' with: '1.3';
				project: 'OB Dev Tests' with: '1.3';
				project: 'AutomaticMethodCategorizer' with: '1.3';
				project: 'RefactoringBrowser' with: '1.6';
				project: 'RefactoringBrowser Tests' with: '1.6';
				project: 'Nile' with: '1.1';
				project: 'Nile Tests' with: '1.1' ;	
				project: 'ProfStef' with: '1.7';
				project: 'ProfStef Tests' with: '1.7';
				project: 'ScriptManager' with: '1.3';
				project: 'Metacello' with: '1.0-beta.27.4';
				project: 'Metacello Tests' with: '1.0-beta.27.4']! !
